pub fn embedding_text(record: &ExperimentRecord) -> StringExpand description
The text an embedder should be given for a record: the same fields BM25 indexes, without the repetition weighting.
pub fn embedding_text(record: &ExperimentRecord) -> StringThe text an embedder should be given for a record: the same fields BM25 indexes, without the repetition weighting.